@@ -14,10 +14,12 @@
 
 mod generate_fn;
 mod generator;
+mod r#impl;
 mod impl_for;
 mod stream_builder;
 
 pub use self::generate_fn::{FnBuilder, FnSelfArg};
 pub use self::generator::Generator;
 pub use self::impl_for::ImplFor;
+pub use self::r#impl::Impl;
 pub use self::stream_builder::{PushParseError, StreamBuilder};
